/hg/gfx-test: Added five new tests into CAGOperationsOnCircleAnd...

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Thu Oct 17 04:34:02 PDT 2013


changeset cb55af58e54c in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=cb55af58e54c
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Thu Oct 17 13:37:49 2013 +0200

	Added five new tests into CAGOperationsOnCircleAndRectangle test
	suite.


diffstat:

 ChangeLog                                                         |    6 +
 src/org/gfxtest/testsuites/CAGOperationsOnCircleAndRectangle.java |  135 +++++++++-
 2 files changed, 131 insertions(+), 10 deletions(-)

diffs (228 lines):

diff -r 7035be323664 -r cb55af58e54c ChangeLog
--- a/ChangeLog	Wed Oct 16 09:42:48 2013 +0200
+++ b/ChangeLog	Thu Oct 17 13:37:49 2013 +0200
@@ -1,3 +1,9 @@
+2013-10-17  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/CAGOperationsOnCircleAndRectangle.java:
+	Added five new tests into CAGOperationsOnCircleAndRectangle test
+	suite.
+
 2013-10-16  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/framework/CommonCAGOperations.java:
diff -r 7035be323664 -r cb55af58e54c src/org/gfxtest/testsuites/CAGOperationsOnCircleAndRectangle.java
--- a/src/org/gfxtest/testsuites/CAGOperationsOnCircleAndRectangle.java	Wed Oct 16 09:42:48 2013 +0200
+++ b/src/org/gfxtest/testsuites/CAGOperationsOnCircleAndRectangle.java	Thu Oct 17 13:37:49 2013 +0200
@@ -69,7 +69,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using union operator. The shape is
      * rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -92,7 +92,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using intersect operator. The shape
      * is rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -115,7 +115,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using subtract operator. The shape
      * is rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -138,7 +138,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using inverse subtract operator.
      * The shape is rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -161,7 +161,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using Xor operator.
      * The shape is rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -1010,7 +1010,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using union operator. The shape is
      * rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -1033,7 +1033,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using subtract operator. The shape
      * is rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -1056,7 +1056,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using inverse subtract operator.
      * The shape is rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -1079,7 +1079,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using intersect operator. The shape
      * is rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -1102,7 +1102,7 @@
     /**
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using XOR operator. The shape is
      * rendered using stroke.
      * 
      * @param image
      *            image to which area is to be drawn
@@ -1949,6 +1949,121 @@
     }
 
     /**
+     * Checks the process of creating and rendering new geometric shape
+     * constructed from circle and rectangle using union operator. The shape is
+     * rendered using stroke paint.
+     * 
+     * @param image
+     *            image to which area is to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testOverlappingCircleAndRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // set stroke color
+        CommonRenderingStyles.setStrokeColor(graphics2d);
+        // create area using union operator
+        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
+        // draw the area
+        graphics2d.draw(area);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Checks the process of creating and rendering new geometric shape
+     * constructed from circle and rectangle using subtract operator. The shape is
+     * rendered using stroke paint.
+     * 
+     * @param image
+     *            image to which area is to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testOverlappingCircleAndRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // set stroke color
+        CommonRenderingStyles.setStrokeColor(graphics2d);
+        // create area using union operator
+        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
+        // draw the area
+        graphics2d.draw(area);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Checks the process of creating and rendering new geometric shape
+     * constructed from circle and rectangle using inverse subtract operator. The shape is
+     * rendered using stroke paint.
+     * 
+     * @param image
+     *            image to which area is to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testOverlappingCircleAndRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // set stroke color
+        CommonRenderingStyles.setStrokeColor(graphics2d);
+        // create area using union operator
+        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
+        // draw the area
+        graphics2d.draw(area);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Checks the process of creating and rendering new geometric shape
+     * constructed from circle and rectangle using intersect operator. The shape is
+     * rendered using stroke paint.
+     * 
+     * @param image
+     *            image to which area is to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testOverlappingCircleAndRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // set stroke color
+        CommonRenderingStyles.setStrokeColor(graphics2d);
+        // create area using union operator
+        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
+        // draw the area
+        graphics2d.draw(area);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Checks the process of creating and rendering new geometric shape
+     * constructed from circle and rectangle using XOR operator. The shape is
+     * rendered using stroke paint.
+     * 
+     * @param image
+     *            image to which area is to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testOverlappingCircleAndRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
+    {
+        // set stroke color
+        CommonRenderingStyles.setStrokeColor(graphics2d);
+        // create area using union operator
+        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
+        // draw the area
+        graphics2d.draw(area);
+        // test result
+        return TestResult.PASSED;
+    }
+
+    /**
      * Entry point to the test suite.
      *
      * @param args not used in this case
@@ -69,7 +69,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using union operator. The shape is
-     * rendered using stroke.
+     * rendered using stroke paint.
      * 
      * @param image
@@ -92,7 +92,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using intersect operator. The shape
-     * is rendered using stroke.
+     * is rendered using stroke paint.
      * 
      * @param image
@@ -115,7 +115,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using subtract operator. The shape
-     * is rendered using stroke.
+     * is rendered using stroke paint.
      * 
      * @param image
@@ -138,7 +138,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using inverse subtract operator.
-     * The shape is rendered using stroke.
+     * The shape is rendered using stroke paint.
      * 
      * @param image
@@ -161,7 +161,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using Xor operator.
-     * The shape is rendered using stroke.
+     * The shape is rendered using stroke paint.
      * 
      * @param image
@@ -1010,7 +1010,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using union operator. The shape is
-     * rendered using stroke.
+     * rendered using stroke paint.
      * 
      * @param image
@@ -1033,7 +1033,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using subtract operator. The shape
-     * is rendered using stroke.
+     * is rendered using stroke paint.
      * 
      * @param image
@@ -1056,7 +1056,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using inverse subtract operator.
-     * The shape is rendered using stroke.
+     * The shape is rendered using stroke paint.
      * 
      * @param image
@@ -1079,7 +1079,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using intersect operator. The shape
-     * is rendered using stroke.
+     * is rendered using stroke paint.
      * 
      * @param image
@@ -1102,7 +1102,7 @@
      * Checks the process of creating and rendering new geometric shape
      * constructed from circle and rectangle using XOR operator. The shape is
-     * rendered using stroke.
+     * rendered using stroke paint.
      * 
      * @param image


More information about the distro-pkg-dev mailing list